import router from './router'
import store from './store'
import NProgress from 'nprogress' // 进度条
import 'nprogress/nprogress.css' // 进度条 style

NProgress.configure({ showSpinner: false }) // 进度条 Configuration

/**
 * @description: 路由前置守卫
 */
router.beforeEach((to, from, next) => {
  NProgress.start()
  document.title = getPageTitle(to.meta.title)

  // 初始化用户信息
  store.commit('user/initUser')
  const power = store.state.user.power
  const token = store.state.user.token

  // 判断 token 是否存在
  if (!token) {
    if (to.path === '/login') {
      next()
    } else {
      // 安卓端兼容性更强的方式，强制跳转登录页
      router.replace('/login')
    }
  } else {
    if (to.path === '/login') {
      next('/') // 已登录访问登录页，重定向首页
    } else {
      // 校验权限
      if (!to.meta.roles || to.meta.roles.indexOf(power) >= 0) {
        next()
      } else {
        next('/') // 权限不足时跳转首页
      }
    }
  }
})

/**
 * @description: 路由完成 结束进度条
 */
router.afterEach(() => {
  NProgress.done() // 结束进度条
})

/**
 * @description: mateTile 和 全局title 组合
 * @return: title
 * @param {*} pageTitle 路由mate.tiele
 */
function getPageTitle (pageTitle) {
  return pageTitle ? `${pageTitle} - ${store.state.settings.title}` : store.state.settings.title
}
